@@ -41,7 +41,8 @@ from random import randint
 
 from grizzly_extras.arguments import split_value, parse_arguments
 
-from ...types import bool_type
+from grizzly.types import bool_type
+
 from . import AtomicVariable
 
 
